@@ -14,6 +14,7 @@ from aws_sagemaker_remote.inference.model import model_create, model_delete, mod
 from aws_sagemaker_remote.inference.endpoint import endpoint_create, endpoint_delete, endpoint_describe, endpoint_invoke
 from aws_sagemaker_remote.inference.endpoint_config import endpoint_config_create, endpoint_config_delete, endpoint_config_describe
 from aws_sagemaker_remote.batch.report import batch_report
+from aws_sagemaker_remote.transform.transform import transform_create
 
 logging.getLogger('boto3').setLevel(logging.CRITICAL)
 logging.getLogger('botocore').setLevel(logging.CRITICAL)
@@ -24,12 +25,18 @@ current_profile = None
 @click.group()
 @click.option('--profile', help='AWS profile. Run `aws-configure` to configure a profile.', default='default')
 def cli(profile='default'):
+    """
+    Set of utilities for managing AWS training, processing, and more.
+    """
     global current_profile
     current_profile = profile
 
 
 @cli.group(name='batch')
 def cli_batch():
+    """
+    S3 batch processing commands
+    """
     pass
 
 
@@ -37,6 +44,9 @@ def cli_batch():
 @click.option('--job', type=str, default=[], multiple=True)
 @click.option('--output', type=str, default='output/batch-report')
 def cli_batch_report(job, output):
+    """
+    Collate a report of completed and failed operations from one or more batch jobs
+    """
     session = boto3.Session(profile_name=current_profile)
     batch_report(
         session=session,
@@ -47,6 +57,9 @@ def cli_batch_report(job, output):
 
 @cli.group(name='json')
 def cli_json():
+    """
+    JSON manipulation commands
+    """
     pass
 
 
@@ -54,6 +67,10 @@ def cli_json():
 """)
 @click.argument('path')
 def cli_json_parse(path):
+    """
+    Print the resolved value of the first argument according
+    to the rules for CSV input processing
+    """
     session = boto3.Session(profile_name=current_profile)
     data = cli_argument(path, session=session)
     print(data)
@@ -64,6 +81,9 @@ def cli_json_parse(path):
 @click.argument('path')
 @click.argument('field')
 def cli_json_read(path, field):
+    """
+    Read field [FIELD] from JSON file at [PATH]
+    """
     session = boto3.Session(profile_name=current_profile)
     path = cli_argument(path, session=session)
     data = json_read(path, field, session=session)
@@ -72,6 +92,9 @@ def cli_json_read(path, field):
 
 @cli.group(name="s3")
 def cli_s3():
+    """
+    S3 management commands
+    """
     pass
 
 
@@ -79,17 +102,24 @@ def cli_s3():
 @click.argument('src')
 @click.argument('dst')
 @click.option('--gz/--no-gz', default=False)
-def cli_s3_upload(src, dst, gz):
+@click.option('--root', type=str, default=".", help="Target path in resulting zip file")
+def cli_s3_upload(src, dst, gz, root):
+    """
+    Upload a file or directory to S3, optionally with GZIP
+    """
     session = boto3.Session(profile_name=current_profile)
     session = sagemaker.Session(session)
-    upload(src=src, dst=dst, gz=gz, session=session)
+    upload(src=src, dst=dst, gz=gz, session=session, root=root)
 
 
 @cli_s3.command(name='concat')
-@click.option('--manifest')
-@click.option('--limit', type=int, default=0)
-@click.option('--output', type=str, required=True)
+@click.option('--manifest', help="Input manifest file")
+@click.option('--limit', type=int, default=0, help="Number of files (0 for all)")
+@click.option('--output', type=str, required=True, help="Output file path")
 def cli_s3_concat(manifest, limit, output):
+    """
+    Download and concatenate multiple files from an S3 manifest
+    """
     session = boto3.Session(profile_name=current_profile)
     session = sagemaker.Session(session)
     s3_concat(
@@ -102,6 +132,9 @@ def cli_s3_concat(manifest, limit, output):
 
 @cli.group()
 def processing():
+    """
+    Processing commands
+    """
     pass
 
 
@@ -114,7 +147,7 @@ def processing():
     required=False)
 def processing_describe_cli(name, field):
     """
-    Describe training job NAME. 
+    Describe training job NAME.
 
     * Print full JSON if FIELD is not specified.
 
@@ -130,8 +163,74 @@ def processing_describe_cli(name, field):
     print(description)
 
 
+@cli.group()
+def transform():
+    """
+    SageMaker batch transform commands
+    """
+    pass
+
+
+@transform.command(name='create')
+@click.option('--base-job-name', help='Transform job base name. If job name not provided, job name is the base job name plus a timestamp.', type=str, default='transform-job')
+@click.option('--job-name', help='Transform job name for tracking in AWS console', type=str, default=None)
+@click.option('--model-name', help='SageMaker Model name', type=str, default=None, required=True)
+@click.option('--concurrency', help='Concurrency (number of concurrent requests to each container)', type=int, default=1)
+@click.option('--timeout', help='Timeout in seconds per request', type=int, default=60*5)
+@click.option('--retries', help='Number of retries for each failed request', type=int, default=0)
+@click.option('--input-s3', help='Input path on S3', type=str, default=None, required=True)
+@click.option('--output-s3', help='Output path on S3', type=str, default=None, required=True)
+@click.option('--input-type', help='Input MIME type ("Content-Type" header)', type=str, default=None, required=True)
+@click.option('--output-type', help='Output MIME type ("Accept" header)', type=str, default=None, required=True)
+@click.option('--instance-type', help='SageMaker Instance type (e.g., ml.m5.large)', type=str, default="ml.m5.large")
+@click.option('--instance-count', help='Number of containers to use (processing will be distributed)', type=int, default=1)
+@click.option('--payload-mb', help='Maximum payload size (MB)', type=int, default=32)
+def transform_create_cli(
+        base_job_name,
+        job_name,
+        model_name,
+        concurrency,
+        timeout,
+        retries,
+        input_s3,
+        output_s3,
+        input_type,
+        output_type,
+        instance_type,
+        instance_count,
+        payload_mb):
+    """
+    Create a batch transformation job for objects in S3
+
+    - Model must already exist in SageMaker
+    - Model instances are deployed
+    - Each S3 object is posted to one of your instances
+    - Results are saved in S3 with the extension ".out"
+    - Model instances are destroyed
+    """
+    transform_create(
+        session=boto3.Session(profile_name=current_profile),
+        base_job_name=base_job_name,
+        job_name=job_name,
+        model_name=model_name,
+        concurrency=concurrency,
+        timeout=timeout,
+        retries=retries,
+        input_s3=input_s3,
+        output_s3=output_s3,
+        input_type=input_type,
+        output_type=output_type,
+        instance_type=instance_type,
+        instance_count=instance_count,
+        payload_mb=payload_mb
+    )
+
+
 @cli.group()
 def training():
+    """
+    SageMaker training commands
+    """
     pass
 
 
@@ -165,7 +264,7 @@ def training_describe_cli(name, field):
 @cli.group()
 def model():
     """
-    Model CLI
+    Model commands
     """
     pass
 
@@ -187,6 +286,9 @@ def model():
 def model_create_cli(
         job, model_artifact, name, inference_image,
         inference_image_path, inference_image_accounts, multimodel, role, force):
+    """
+    Create a SageMaker model
+    """
     session = boto3.Session(profile_name=current_profile)
     session = sagemaker.Session(session)
     model_create(
@@ -235,7 +337,7 @@ def model_describe_cli(name, field):
 @cli.group()
 def endpoint_config():
     """
-    Endpoint config CLI
+    Endpoint config comands
     """
     pass
 
@@ -249,6 +351,9 @@ def endpoint_config():
     default='ml.t2.medium')
 @click.option('--force/--no-force', default=False)
 def endpoint_config_create_cli(name, model, instance_type, force):
+    """
+    Create an endpoint configuration
+    """
     session = boto3.Session(profile_name=current_profile)
     session = sagemaker.Session(session)
     endpoint_config_create(
@@ -295,7 +400,7 @@ def endpoint_config_delete_cli(name):
 @cli.group()
 def endpoint():
     """
-    Endpoint CLI
+    Endpoint commands
     """
     pass
 
@@ -305,6 +410,9 @@ def endpoint():
 @click.option('--config', type=str, default=None, help='Name of endpoint config')
 @click.option('--force/--no-force', default=False, help='Overwrite existing endpoint')
 def endpoint_create_cli(name, config, force):
+    """
+    Create a SageMaker endpoint
+    """
     session = boto3.Session(profile_name=current_profile)
     client = session.client('sagemaker')
     endpoint_create(
@@ -317,6 +425,9 @@ def endpoint_create_cli(name, config, force):
 @endpoint.command(name='delete')
 @click.argument('name', type=str)
 def endpoint_delete_cli(name):
+    """
+    Delete a SageMaker endpoint
+    """
     session = boto3.Session(profile_name=current_profile)
     client = session.client('sagemaker')
     endpoint_delete(
@@ -329,6 +440,9 @@ def endpoint_delete_cli(name):
 @click.argument('name', type=str)
 @click.argument('field', type=str, default=None, required=False)
 def endpoint_describe_cli(name, field):
+    """
+    Describe a SageMaker endpoint
+    """
     session = boto3.Session(profile_name=current_profile)
     client = session.client('sagemaker')
     description = endpoint_describe(
@@ -348,6 +462,9 @@ def endpoint_describe_cli(name, field):
 @click.option('--output-type', type=str, default=None)
 @click.option('--model-dir', type=str, default=None)
 def endpoint_invoke_cli(name, model, variant, input, output, input_type, output_type, model_dir):
+    """
+    Invoke a SageMaker endpoint or a SageMaker-style model in a local directory
+    """
     session = boto3.Session(profile_name=current_profile)
     runtime_client = session.client('sagemaker-runtime')
     result = endpoint_invoke(
@@ -370,7 +487,7 @@ def endpoint_invoke_cli(name, model, variant, input, output, input_type, output_
 @cli.group()
 def ecr():
     """
-    ECR CLI
+    ECR commands
     """
     pass
 
@@ -378,6 +495,7 @@ def ecr():
 @ecr.group(name='build')
 def ecr_build():
     """
+    Commands to build ECR images
     """
     pass
 
@@ -387,6 +505,9 @@ def ecr_build():
 @click.option('--pull/--no-pull', default=True)
 @click.option('--push/--no-push', default=True)
 def ecr_build_all(cache, pull, push):
+    """
+    Build all available docker images
+    """
     session = boto3.Session(profile_name=current_profile)
     for image in Images.ALL:
         print("Building Image {}".format(image.name))
@@ -399,7 +520,7 @@ def ecr_build_all(cache, pull, push):
 
 
 def ecr_image_build_cli(image):
-    @ecr_build.command(name=image.name)
+    @ecr_build.command(name=image.name, help=f"Build the [{image.tag}] image")
     @click.option('--path', type=str, default=image.path)
     @click.option('--tag', type=str, default=image.tag)
     @click.option('--account', type=str, default=image.accounts, multiple=True)
