@@ -34,6 +34,18 @@ class Images(object):
         tag='aws-sagemaker-remote-inference:latest',
         accounts=['763104351884']
     )
+    INFERENCE_PY27GPUTF = Image(
+        name='inference:py27-gpu-tf',
+        path=os.path.abspath(os.path.join(__file__, '../inference')),
+        tag='aws-sagemaker-remote-inference:py27-gpu-tf',
+        accounts=[]
+    )
+    INFERENCE_PY27TF = Image(
+        name='inference:py27-tf',
+        path=os.path.abspath(os.path.join(__file__, '../inference')),
+        tag='aws-sagemaker-remote-inference:py27-tf',
+        accounts=[]
+    )
 
     PROCESSING = Image(
         name='processing',
@@ -41,6 +53,12 @@ class Images(object):
         tag='aws-sagemaker-remote-processing:latest',
         accounts=['763104351884']
     )
+    PROCESSING_PY27GPUTF = Image(
+        name='processing:py27-gpu-tf',
+        path=os.path.abspath(os.path.join(__file__, '../processing')),
+        tag='aws-sagemaker-remote-processing:py27-gpu-tf',
+        accounts=[]
+    )
 
     TRAINING = Image(
         name='training',
@@ -58,7 +76,10 @@ class Images(object):
 
     ALL = [
         INFERENCE,
+        INFERENCE_PY27GPUTF,
+        INFERENCE_PY27TF,
         PROCESSING,
+        PROCESSING_PY27GPUTF,
         TRAINING,
         TRAINING_GPU
     ]
