@@ -5,6 +5,8 @@ import os
 def module_path(module):
     if isinstance(module, ModuleType):
         path = os.path.abspath(module.__file__)
-        return os.path.dirname(path)
+        if path.endswith("__init__.py"):
+            path = os.path.dirname(path)
+        return path
     else:
         return module
